Changelog
==============

0.4.0
------
* Updated jQuery Smooth Scroll to v1.4.12.
* Updated h5bp.css to v4.3.0.
* Updated normalize.css to v1.1.3.
* Removed Chrome Frame value from meta content attribute.
* Added initial CDNJS load for jQuery Dynamic Formset, jQuery ScrollTo and jQuery Smooth Scroll.
* Added Font Awesome (3.2.1).
* Added djfront_fontawesome template tag.
* Added djfront_fontawesome_ie template tag.
* Fixed jQuery UI initial load.

0.3.1
------
* Fixed URL to TWBS Glyphicons in bootstrap.min.css

0.3.0
------
* Updated Twitter Bootstrap to v3.0.0
* Added djfrontend_twbs_theme_css template tag
* Added bootstrap-theme.css and bootstrap-theme.min.css
* Added djfrontend_jquery_scrollto template tag
* Added jquery.scrollTo.js and jquery.scrollTo.min.js
* Removed djfrontend_twbs_glyphicons template tag
* Removed bootstrap-glyphicons.css

0.2.1
------
* Updated Twitter Bootstrap to v3.0.0 RC2

0.2.0
------
* Updated jQuery to v1.10.2 and v2.0.3
* Updated Twitter Bootstrap to v3.0.0 RC1
* Added djfrontend_twbs_glyphicons template tag
* Added cdnjs initial loading for Modernizr and jQuery DataTables
* Removed djfrontend_twbs_responsive_css template tag
* Removed bootstrap-typeahead.js

0.1.0
------
* Initial release